/**
 * @Copyright (c) Microsoft Corporation.  All rights reserved.
 *
 * @file Client side component manifest definition.
 */
import { IClientSideComponentLoaderConfiguration } from './IClientSideComponentLoaderConfiguration';
import { IClientSideManifestBase } from './IClientSideManifestBase';
/**
 * Definition: A set of localized strings.
 * Supported values:
 * * An Id referring to a localized resource. In this case it requires an 'id' key.
 * * A dictionary of locale keys to strings. In this case it requires a 'default' key.
 * Example 1: "My Application"
 *          {
 *            "id": "$myStrings:myStrings.MyApplication;"
 *          }
 * Example 2: "My Application"
 *          {
 *            "default": "My Application"
 *            "en-us": "My Application",
 *            "fr-fr": "Ma demande",
 *            "zh": "我的應用程式"
 *          }
 *
 * Notes on strings id:
 * Ids have the following structure: $<resourceName>:<expression>;
 * resourceName needs to be a localizedResource in the config.json.
 * expression is an expression that will be evaluated to access the string from the resource module.
 *
 * If your resource is a dictionary, access it through "$resource:resource.MyString;"
 * or "$resource:resource[\"MyString\"];"
 * For more complex cases, run an appropriate expression to access your resource and return the string.
 *
 * @public
 */
export interface ILocalizedString {
    default?: string;
    id?: string;
    [locale: string]: string | undefined;
}
/**
 * Type of client side component.
 */
export declare type ComponentType = 'Application' | 'WebPart' | 'Library' | 'Extension';
/**
 * All client side components built on the SharePoint framework need a valid component manifest. This interface
 * represents properties that are required by all types of client side components like Applications and Web Parts.
 * Component specific manifests will extend this interface to add properties required by that component type.
 *
 * The schema of this manifest is owned and versioned by Microsoft. Following rules should be followed while changing
 * this schema. This set of rules can also be called the "manifest upgrade rules".
 *
 *   -  For minor changes, new properties can be added to this schema in a backwards-compatible way. i.e. the code
 *      that processes the manifest should be able to handle the absence of those new properties.
 *   -  Try to model your changes as minor SemVer increments.  Major version changes should be avoided because they
 *      impose a migration cost on developers.
 *   -  The 'manifestVersion' should be bumped for all small or big changes.
 *
 * @internalremarks - This schema should be at all times kept in sync with the server-side code file
 *   SPClientSideComponentManifest.cs.
 *
 * @public
 */
export interface IClientSideComponentManifest extends IClientSideManifestBase {
    /**
     * Definition: Type of client side component. Components with the "Application" type are defined by the
     *  "IClientSideApplicationManifest" interface. Components with the "WebPart" type are defined by the
     *  "IClientSideWebPartManifest" interface. Components with the "Library" type are defined by the
     *  "IClientSideLibraryManifest" interface.
     * Usage: To help bundling, loading, enumeration, and initialization of components based on their contents.
     * Required: yes
     * Localized: no
     * Supported values: "Application", "WebPart", "Library", "Extension"
     * Example: "Application"
     */
    componentType: ComponentType;
    /**
     * Definition: A short name usually given by developer. It does not need to be localized and is expected to stay
     * the same through the lifetime of the component. If an application overrides the ClientSideApplication.alias
     * property, ClientSideApplication.alias is given precedence over the value provided in the manifest.
     * Usage: A short name to identify a client side component by developer.
     * Required: no
     * Localized: no
     * Supported values: Allowed characters are a-z, A-Z, and '-'. Not longer than 40 characters.
     * Example: "NewFeed"
     *
     * @internalremarks - telemetry data is categorized based on alias. If alias changes, new telemetry date for this
     * component will be put in a new category. It breaks history data if alias changes.
     */
    alias: string;
    /**
     * Definition: An auto-generated value for internal use. Do not add or use it.
     * Usage: Not to be used by third-party developers.
     * Required: no
     *
     * @internal
     *
     * @internalremarks - this property indicates whether the component is first-party or third-party. IsInternal is true
     * for first-party, false for third-party. The value is controlled by server side code. It is used when framework
     * needs to differentiate between behaviors for first-party components and third-party, like in telemetry.
     */
    isInternal?: boolean;
    /**
     * Definition: An auto-generated value for internal use. Do not add or use it.
     * Usage: Not to be used by third-party developers.
     * Required: no
     *
     * @internal
     *
     * @internalremarks - this property is true when the manifest comes from the debug query param.
     */
    _isDebug?: boolean;
    /**
     * Definition: Client side component version. The value of this field is expected to be controlled by the developer
     *  of the client side component. The purpose of this field is to help client side component developers upgrade their
     *  client side components in a managed way. This helps the consumers of the client side component make decisions
     *  about when and how to upgrade the client side component. As the developer evolves the code for their client side
     *  component, they can decide to bump the MAJOR, MINOR or PATCH version of the component. All incompatible API
     *  changes should result in a MAJOR version bump. Backwards compatible functionality changes should result in a
     *  MINOR version bump, and backwards compatible bug fixes should result in a PATCH version bump. Please see
     *  http://semver.org for more details on how to manage the version of your components.
     * Usage: Versioning and evolving a client side component safely in a controlled way.
     * Required: yes
     * Localized: no
     * Supported values: string representing a semantic version (http://semver.org) i.e. MAJOR.MINOR.PATCH
     * Example: "1.0.0"
     */
    version: string;
    /**
     * Definition: A list of component manifests that must be preloaded alongside this component.
     * These may include external resources that are needed during initial render, or components that should
     * be loaded only on demand.
     * Required: no
     * Supported values: an array of manifest IDs
     * Example: [ "66665f5e-307f-41cf-9fec-17c5ea20f0ca", "2d02eafb-eb82-47d2-98ac-dcac4aa63969" ]
     *
     * @alpha
     */
    preloadComponents?: string[];
    /**
     * This property is provided for backwards compatibility.  It no longer has any effect.
     * @deprecated Use requiresCustomScript instead of safeWithCustomScriptDisabled.
     */
    safeWithCustomScriptDisabled?: boolean;
    /**
     * Definition: If true, the component can only be installed on sites where Custom Script is enabled.
     *  This should be set to true if the component allows authors to execute arbitrary scripts on the page.
     *  See https://support.office.com/en-us/article/Turn-scripting-capabilities-on-or-off-1f2c515f-5d7e-448a-9fd7-835da935584f for more information.
     *  Defaults to false.
     * Usage: Requires Custom Script to be allowed in order for this component to be installed and run.
     * Required: no
     * Localized: no
     * Supported values: true or false
     * Example: false
     */
    requiresCustomScript?: boolean;
    /**
     * Definition: This portion of the configuration describes how the component is to be loaded and initialized by a
     *  client. It contains an enumeration of scripts that the component requires along with a single entrypoint script.
     * Usage: Loading a component.
     * Required: yes
     *
     * See IClientSideComponentLoaderConfiguration.ts for more information and examples.
     *
     * @beta
     */
    loaderConfig: IClientSideComponentLoaderConfiguration;
    /**
     * Definitions: Property bag for the component manifest.
     * Usage: Provide a set of properties for the component, that doesn't change across instances.
     * Required.no
     * Localized: no
     * Supported values: Key-value pairs with a string key.
     *
     * @internal
     */
    properties?: {
        [key: string]: any;
    };
}
